Subpackages
===========

.. toctree::

    pysight.ascii_list_file_parser
    pysight.binary_list_file_parser
    pysight.nd_hist_generator

Submodules
==========

pysight\.main module
--------------------

.. automodule:: pysight.main
    :members:
    :undoc-members:
    :show-inheritance:

pysight\.tkinter\_gui\_multiscaler module
-----------------------------------------

.. automodule:: pysight.tkinter_gui_multiscaler
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pysight
    :members:
    :undoc-members:
    :show-inheritance:
